@@ -32,7 +32,7 @@ use locale;
 use vars qw($VERSION $LH);
 use strict;
 
-$VERSION = '1.22';
+$VERSION = '1.24';
 
 $LH = App::rdapper::l10n->get_handle;
 
@@ -722,7 +722,10 @@ sub print_jcard_property {
             $value = $VCARD_KIND_DISPLAY_NAME{$value} || $value;
 
         } elsif ('TEL' eq uc($property->type)) {
-            if (any { 'fax' eq lc($_) } @{$property->param('type')}) {
+            my $types = $property->param('type');
+            $types = [ $types ] if (q{ARRAY} ne ref($types));
+
+            if (any { 'fax' eq lc($_) } @{$types}) {
                 $label = _('Fax');
 
             } else {
@@ -781,7 +784,7 @@ sub print_nameserver {
         $package->print_kv(_('IP Address'), $ip->short, $indent);
     }
 
-    my @types = $nameserver->dns_ttl_values;
+    my @types = $nameserver->dns_ttl_types;
     $package->display_ttl_values($nameserver, $indent) if (scalar(@types) > 0);
 }
 
